==> rule-center-client-api-1.0.1-20210329.093048-43-sources.jar: com/xforceplus/ant/coop/rule/center/client/api/cc/EnumConfigApi.java <==
package com.xforceplus.ant.coop.rule.center.client.api.cc;

import com.xforceplus.ant.coop.rule.center.client.data.cc.response.ListEnumConfig;
import com.xforceplus.ant.coop.rule.center.client.data.utils.BaseResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * Describe: 枚举配置
 *
 * @Author xiezhongyong
 * @Date 2020-04-29
 */
@Api(value = "enum-configs", description = "枚举配置 接口服务")
public interface EnumConfigApi {


    @ApiOperation("通过配置类型查询枚举配置列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "configType", value = "配置类型", dataType = "String", paramType = "path")}
    )
    @RequestMapping(value = "/enum-configs/{configType}", method = RequestMethod.GET, produces = {MediaType.APPLICATION_JSON_VALUE})
    BaseResult<List<ListEnumConfig>> listByConfigType(@PathVariable(value = "configType") String configType);


    @ApiOperation("拆票备注字段枚举配置列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "configCodes", value = "字段名称列表", dataType = "String", paramType = "query"),
            @ApiImplicitParam(name = "configObjId", value = "配置ID", dataType = "Long", paramType = "query"),
            @ApiImplicitParam(name = "billTypeName", value = "单据类型", dataType = "String", paramType = "query")}
    )
    @RequestMapping(value = "/enum-configs/split-remark", method = RequestMethod.GET, produces = {MediaType.APPLICATION_JSON_VALUE})
    BaseResult<List<ListEnumConfig>> splitRemarkList(@RequestParam(value = "configCodes", required = false) List<String> configCodes,
                                          @RequestParam(value = "configObjId", required = false) Long configObjId,
                                          @RequestParam(value = "billTypeName", required = false) String billTypeName);

}

==> rule-center-client-api-1.0.3-20251104.024620-1-sources.jar: com/xforceplus/ant/coop/rule/center/client/api/cc/EnumConfigApi.java <==
package com.xforceplus.ant.coop.rule.center.client.api.cc;

import com.xforceplus.ant.coop.rule.center.client.data.cc.response.ListEnumConfig;
import com.xforceplus.ant.coop.rule.center.client.data.utils.BaseResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * Describe: 枚举配置
 *
 * @Author xiezhongyong
 * @Date 2020-04-29
 */
@Api(value = "enum-configs", description = "枚举配置 接口服务")
public interface EnumConfigApi {


    @ApiOperation("通过配置类型查询枚举配置列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "configType", value = "配置类型", dataType = "String", paramType = "path")}
    )
    @RequestMapping(value = "/enum-configs/{configType}", method = RequestMethod.GET, produces = {MediaType.APPLICATION_JSON_VALUE})
    BaseResult<List<ListEnumConfig>> listByConfigType(@PathVariable(value = "configType") String configType);


    @ApiOperation("拆票备注字段枚举配置列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "configCodes", value = "字段名称列表", dataType = "String", paramType = "query"),
            @ApiImplicitParam(name = "configObjId", value = "配置ID", dataType = "Long", paramType = "query"),
            @ApiImplicitParam(name = "billTypeName", value = "单据类型", dataType = "String", paramType = "query")}
    )
    @RequestMapping(value = "/enum-configs/split-remark", method = RequestMethod.GET, produces = {MediaType.APPLICATION_JSON_VALUE})
    BaseResult<List<ListEnumConfig>> splitRemarkList(@RequestParam(value = "configCodes", required = false) List<String> configCodes,
                                          @RequestParam(value = "configObjId", required = false) Long configObjId,
                                          @RequestParam(value = "billTypeName", required = false) String billTypeName);

    @ApiOperation("拆票规则枚举配置列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "configCodes", value = "字段名称列表", dataType = "String", paramType = "query"),
            @ApiImplicitParam(name = "configType", value = "配置类型：RemarkEnum=备注字段；SplitEnum=拆分字段", dataType = "String", paramType = "query"),
            @ApiImplicitParam(name = "configObjId", value = "配置ID", dataType = "Long", paramType = "query"),
            @ApiImplicitParam(name = "billTypeName", value = "单据类型", dataType = "String", paramType = "query")}
    )
    @RequestMapping(value = "/enum-configs/split-invoice", method = RequestMethod.GET, produces = {MediaType.APPLICATION_JSON_VALUE})
    BaseResult<List<ListEnumConfig>> splitEnumList(@RequestParam(value = "configCodes", required = false) List<String> configCodes,
                                          @RequestParam(value = "configType", required = false) String configType,
                                          @RequestParam(value = "configObjId", required = false) Long configObjId,
                                          @RequestParam(value = "billTypeName", required = false) String billTypeName);

}
